@@ -65,6 +65,19 @@ class Http2Client:
         response.raise_for_status()
         return self._handle_response(response)
 
+    def patch(self, endpoint: str, data: dict = None, json: dict = None,headers: dict = None) -> dict:
+        """
+        发送 patch 请求。
+
+        :param endpoint: API 端点
+        :param data: 表单数据
+        :param headers: 请求头
+        :return: JSON 响应
+        """
+        response = self.client.patch(endpoint, data=data, json=json, headers=self._merge_headers(headers))
+        response.raise_for_status()
+        return self._handle_response(response)
+
     def delete(self, endpoint: str, headers: dict = None) -> dict:
         """
         发送 DELETE 请求。
