@@ -3,5 +3,6 @@
 # @email: maoyongfan@163.com
 # @Date: 2025/2/28 23:04
 from .datetime_change import (timeDifference_seconds, get_localTime, get_strftime, get_utc_seconds,
-                              get_second_sunday_march_utc_timestamp, get_nov_first_sunday_timestamp)
+                              get_second_sunday_march_utc_timestamp, get_nov_first_sunday_timestamp,
+                              get_nov_first_sunday_timestamp2)
 
